<xsl:stylesheet	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" >

	<xsl:output method="html" />
	<xsl:template match="//familytree">
        <html>
		<xsl:call-template name="html-header"/>
        <body>
        <a name="top"><!-- Seitenanfang --></a>
        <center>
        <p>
			<h1>Stammbaum der Familie <xsl:value-of select="@id"/></h1>
	        <small>
	        	(Erstellt von <xsl:value-of select="author"/>,
	        	letzte &#196;nderung am <xsl:value-of select="version"/>: 
	        	<xsl:value-of select="count(member)"/> Personen)
	        </small>
            <hr />
            <xsl:call-template name="initials"/>
	        <hr />
            <xsl:call-template name="index"/>

            <br /><br /><br />
            <hr />
            <br /><br /><br />
			<xsl:apply-templates select="member"/>
		</p>
        </center>
        </body>
        </html>
	</xsl:template>


    <!--
    	HTML-Header incl. Meta-Tags
    -->
    <xsl:template name="html-header">
		<head>
        <title>Stammbaum der Familie <xsl:value-of select="//familytree/@id"/></title>
        <link rel="stylesheet" type="text/css" href="style.css" />
	    <script language="JavaScript">
	    	function showPic(pic) {
                myPic = new Image();
                myPic.src = 'image/' + pic;
				// imgwin = window.open( myPic.src, 'aPic', 'width=' + (myPic.width + 20) + ',height=' + (myPic.height + 20) + ',location=no,menubar=no,status=no,toolbar=no,resizable=yes' );
    	    	imgwin = window.open( myPic.src, 'aPic', 'location=no,menubar=no,status=no,toolbar=no,resizable=yes' );
	        	imgwin.focus();
		    }
    	</script>
		</head>
	</xsl:template>


    <!--
        Link-Liste der vorkommenden Initialen
    -->
	<xsl:template name="initials">
		<xsl:for-each select="member">
			<xsl:sort order="ascending" select="@name"/>
			<xsl:variable name="initiale" select="substring(@name, 1, 1)"/>

			<xsl:if test="not(preceding::node()[substring(@name, 1, 1)=$initiale])">
				<a>
					<xsl:attribute name="href">#<xsl:value-of select="$initiale"/></xsl:attribute>
					<xsl:value-of select="$initiale"/>
				</a>
				<xsl:text> </xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>


    <!--
        Alphabetischer Index aller Personen mit Einsprung-Link
    -->
	<xsl:template name="index">

		<table border="0" cellspacing="0" cellpadding="1">

			<xsl:for-each select="member">
				<xsl:sort order="ascending" select="@name"/>
				<xsl:variable name="initiale" select="substring(@name, 1, 1)"/>

				<xsl:if test="not(preceding::node()[substring(@name, 1, 1)=$initiale])">
   					<tr>
						<td colspan="2" align="center">
							<a>
								<xsl:attribute name="name"><xsl:value-of select="$initiale"/></xsl:attribute>
	                		    <h2><br /><xsl:value-of select="$initiale"/></h2>
							</a>
        	            </td>
            	    </tr>

					<xsl:for-each select="//member[substring(@name, 1, 1)=$initiale]">
						<xsl:sort order="ascending" select="@name"/>
						<xsl:sort order="ascending" select="@nickname"/>
						<xsl:sort order="ascending" data-type="number" select="substring(birth-date, string-length(birth-date) - 3, 4)"/>
	       				<tr>
							<td>
						        <a>
       								<xsl:attribute name="href">#id<xsl:value-of select="@id"/></xsl:attribute>
	    					        <xsl:value-of select="@name"/><xsl:text>, </xsl:text>
    					    	    <xsl:value-of select="@nickname"/>
			            	    </a>
							</td>
							<td>
						        <a>
       								<xsl:attribute name="href">#id<xsl:value-of select="@id"/></xsl:attribute>
					    		    (<xsl:choose>
	                                    <xsl:when test="string-length(birth-date)>3">geb.
		                                    <xsl:value-of select="substring(birth-date, string-length(birth-date) - 3, 4)"/>
	                                    </xsl:when>
	                                    <xsl:otherwise>ohne Angabe</xsl:otherwise>
                                    </xsl:choose>)
				                </a>
							</td>
						</tr>
					</xsl:for-each>
				</xsl:if>
			</xsl:for-each>
		</table>
	</xsl:template>


    <!--
        Ausgabe einer einzelnen Person
    -->
    <xsl:template match="member">
        <a>
            <xsl:attribute name="name">id<xsl:value-of select="@id"/></xsl:attribute>
        </a>

        <p>&#160;</p>

        <!-- Rahmentabelle -->
		<table border="4" cellspacing="0" cellpadding="0" bordercolordark="#606060"><tr><td>

		<table border="1" cellspacing="0" cellpadding="10" bgcolor="#f8f0e8">
			<tr>
				<td>
                    Vater:
			        <a>
						<xsl:variable name="myFatherID"><xsl:value-of select="father/@id"/></xsl:variable>
        				<xsl:attribute name="href">#id<xsl:value-of select="$myFatherID"/></xsl:attribute>
			            <xsl:value-of select="//member[@id=$myFatherID]/@nickname"/><xsl:text> </xsl:text>
			            <xsl:value-of select="//member[@id=$myFatherID]/@name"/>
					</a>
	            </td>
				<td>
                    Mutter:
			        <a>
						<xsl:variable name="myMotherID"><xsl:value-of select="mother/@id"/></xsl:variable>
        				<xsl:attribute name="href">#id<xsl:value-of select="$myMotherID"/></xsl:attribute>
			            <xsl:value-of select="//member[@id=$myMotherID]/@nickname"/><xsl:text> </xsl:text>
			            <xsl:value-of select="//member[@id=$myMotherID]/@name"/>
					</a>
	            </td>
			</tr>
			<tr>
				<td colspan="2" align="center" class="big" bgcolor="#ffffff">
                   	<xsl:value-of select="@nickname"/><xsl:text> </xsl:text>
					<xsl:value-of select="@name"/><xsl:text> </xsl:text>
				</td>
			</tr>
			<tr>
				<td colspan="2">
					<xsl:if test="string-length(birth-date)>0">
						Geboren <xsl:value-of select="birth-date"/>
							<xsl:if test="string-length(birth-place)>0">
		                	    in <xsl:value-of select="birth-place"/>
							</xsl:if>
							<xsl:if test="string-length(birth-name)>0">
		            	        als <xsl:value-of select="fullname"/>
                                <xsl:text> </xsl:text>
		    	                <xsl:value-of select="birth-name"/>
							</xsl:if>
	                    <br />
					</xsl:if>
					<xsl:if test="string-length(death-date)>0">
						Gestorben <xsl:value-of select="death-date"/>
							<xsl:if test="string-length(death-place)>0">
		                	    in <xsl:value-of select="death-place"/>
							</xsl:if>
							<xsl:if test="string-length(death-name)>0">
		            	        als <xsl:value-of select="title"/>
                                <xsl:text> </xsl:text>
		            	        <xsl:value-of select="fullname"/>
                                <xsl:text> </xsl:text>
		    	                <xsl:value-of select="death-name"/>
							</xsl:if>
	                    <br />
					</xsl:if>
                    <br />

					<xsl:if test="count(image)>0">

						<table border="0" cellspacing="0" cellpadding="5" align="center">
							<tr>

								<xsl:for-each select="image">
									<xsl:sort data-type="number" order="ascending" select="@order"/>

									<xsl:if test="boolean(@href)">
										<td>
											<a>
												<!-- xsl:attribute name="href">image/<xsl:value-of select="@href"/></xsl:attribute -->
												<!-- xsl:attribute name="target">_blank</xsl:attribute -->
												<xsl:attribute name="href">javascript:showPic('<xsl:value-of select="@href"/>')</xsl:attribute>
												<img>
													<xsl:attribute name="src">thumb/<xsl:value-of select="@href"/></xsl:attribute>
													<xsl:attribute name="border">0</xsl:attribute>
													<xsl:attribute name="width">100</xsl:attribute>
													<xsl:attribute name="alt">Anklicken zum Vergr&#246;&#223;ern</xsl:attribute>
												</img>
												<br />
												<xsl:value-of select="."/>
											</a>
										</td>
									</xsl:if>

								</xsl:for-each>

							</tr>
						</table>

					</xsl:if>

				</td>
			</tr>
			<tr>
				<td colspan="2">
					<table border="1" cellspacing="0" cellpadding="5" width="100%">
						<tr>

					        <xsl:for-each select="partner">
					            <xsl:sort data-type="number" select="@no"/>

								<td valign="top">

				    	        	Partner<br />

									<a>
										<xsl:variable name="partnerID"><xsl:value-of select="@id"/></xsl:variable>
										<xsl:attribute name="href">#id<xsl:value-of select="$partnerID"/></xsl:attribute>
										<xsl:value-of select="//member[@id=$partnerID]/@nickname"/><xsl:text> </xsl:text>
										<xsl:value-of select="//member[@id=$partnerID]/@name"/><br />
									</a>

									<xsl:if test="string-length(@start)>0">
					    	            verheiratet seit <xsl:value-of select="@start"/><br />
									</xsl:if>

									<xsl:if test="string-length(@end)>0">
					    	            bis <xsl:value-of select="@end"/><br />
									</xsl:if>

									<xsl:if test="count(child)>0">

										<br />
										Gemeinsame Kinder:<br />

				        		        <xsl:for-each select="child">
       									    <xsl:sort data-type="number" select="@no"/>

											<a>
		        					            <xsl:variable name="childID"><xsl:value-of select="@id"/></xsl:variable>
												<xsl:attribute name="href">#id<xsl:value-of select="$childID"/></xsl:attribute>
               							    	<xsl:value-of select="//member[@id=$childID]/@nickname"/><xsl:text> </xsl:text>
				   	    		            	<xsl:value-of select="//member[@id=$childID]/@name"/> <br />
											</a>

								        </xsl:for-each>
									</xsl:if>

								</td>

					        </xsl:for-each>

						</tr>
					</table>
                    <table border="0" cellspacing="0" cellpadding="0" width="100%">
						<tr>
		                    <td align="left"><sub>(#<xsl:value-of select="@id"/>)</sub></td>
		                    <td align="right" valign="bottom"><a href="#top"><img src="up.gif" border="0" alt="Zum Seitenanfang"/></a></td>
						</tr>
					</table>
				</td>
			</tr>
		</table>

		</td></tr></table>

        <!-- Etwas Abstand halten -->
		<p><br />&#160;<br />&#160;<br />&#160;</p>
    </xsl:template>

</xsl:stylesheet>